
# Model Zoo

models from tw/models

| type       | pretrain |         Model          |  Acc@1  |  Acc@5  | Param(M) | FLOPs(M) | Image Size |
|:-----------|:--------:|:----------------------:|:-------:|:-------:|:--------:|:--------:|:----------:|
| backbone2d |    Y     |        alexnet         | 54.932  | 78.035  |          |          |    224     |
| backbone2d |    Y     |         vgg11          | 66.626  | 86.360  |          |          |            |
| backbone2d |    Y     |         vgg13          | 67.724  | 88.103  |          |          |            |
| backbone2d |    Y     |         vgg16          | 69.887  | 89.499  |          |          |            |
| backbone2d |    Y     |         vgg19          | 70.707  | 89.891  |          |          |            |
| backbone2d |    Y     |        vgg11_bn        | 68.592  | 88.737  |          |          |            |
| backbone2d |    Y     |        vgg13_bn        | 68.906  | 88.799  |          |          |            |
| backbone2d |    Y     |        vgg16_bn        | 71.413  | 90.421  |          |          |            |
| backbone2d |    Y     |        vgg19_bn        | 72.384  | 90.948  |          |          |            |
| backbone2d |    Y     |      densenet121       | 74.966  | 92.254  |          |          |            |
| backbone2d |    Y     |      densenet161       | 77.685  | 93.834  |          |          |            |
| backbone2d |    Y     |      densenet169       | 76.163  | 93.180  |          |          |            |
| backbone2d |    Y     |      densenet201       | 77.361  | 93.634  |          |          |            |
| backbone2d |    Y     |       googlenet        | 70.269  | 89.823  |          |          |            |
| backbone2d |    Y     |        resnet18        | 68.042  | 88.175  |          |          |            |
| backbone2d |    Y     |        resnet34        | 72.048  | 90.645  |          |          |            |
| backbone2d |    Y     |        resnet50        | 74.068  | 91.926  |          |          |            |
| backbone2d |    Y     |       resnet101        | 76.259  | 93.076  |          |          |            |
| backbone2d |    Y     |       resnet152        | 77.139  | 93.556  |          |          |            |
| backbone2d |    Y     |    resnext50_32x4d     | 76.201  | 93.046  |          |          |            |
| backbone2d |    Y     |    resnext101_32x8d    | 78.147  | 94.029  |          |          |            |
| backbone2d |    Y     |    wide_resnet50_2     | 76.935  | 93.386  |          |          |            |
| backbone2d |    Y     |    wide_resnet101_2    | 77.489  | 93.654  |          |          |            |
| backbone2d |    Y     |     squeezenet1_0      | 56.152  | 79.116  |          |          |            |
| backbone2d |    Y     |     squeezenet1_1      | 54.948  | 78.193  |          |          |            |
| backbone2d |    Y     |   shufflenet_v2_x0_5   | 56.066  | 78.207  |          |          |            |
| backbone2d |    Y     |   shufflenet_v2_x1_0   | 66.758  | 86.614  |          |          |            |
| backbone2d |    Y     |        senet154        | 81.066  | 95.399  |          |          |            |
| backbone2d |    Y     |      se_resnet50       | 77.411  | 93.580  |          |          |            |
| backbone2d |    Y     |      se_resnet101      | 78.017  | 94.117  |          |          |            |
| backbone2d |    Y     |      se_resnet152      | 78.520  | 94.387  |          |          |            |
| backbone2d |    Y     |   se_resnext50_32x4d   | 78.774  | 94.305  |          |          |            |
| backbone2d |    Y     |  se_resnext101_32x4d   | 80.094  | 94.965  |          |          |            |
| backbone2d |    Y     |       resnet18d        | 71.6171 | 90.4191 |          |          |            |
| backbone2d |    Y     |       resnet34d        | 76.5455 | 93.1262 |          |          |            |
| backbone2d |    Y     |       resnet26d        | 75.2519 | 92.4864 |          |          |            |
| backbone2d |    Y     |        resnet26        | 74.1303 | 91.9366 |          |          |            |
| backbone2d |    Y     |       resnet50d        | 79.9204 | 94.8596 |          |          |            |
| backbone2d |    Y     |       resnet101d       | 81.1940 | 95.5074 |          |          |            |
| backbone2d |    Y     |       resnet152d       | 81.9818 | 95.8873 |          |          |            |
| backbone2d |    Y     |       resnet200d       | 82.1037 | 95.9833 |          |          |            |
| backbone2d |    Y     |    resnext50d_32x4d    | 78.9987 | 94.4598 |          |          |            |
| backbone2d |    N     |    resnext101_32x4d    |         |         |          |          |            |
| backbone2d |    N     |    resnext101_64x4d    |         |         |          |          |            |
| backbone2d |    Y     |  ig_resnext101_32x8d   | 82.1077 | 96.6131 |          |          |            |
| backbone2d |    Y     |  ig_resnext101_32x16d  | 83.6732 | 97.1049 |          |          |            |
| backbone2d |    Y     |  ig_resnext101_32x32d  | 84.6069 | 97.4168 |          |          |            |
| backbone2d |    Y     |  ig_resnext101_32x48d  | 85.0248 | 97.4868 |          |          |            |
| backbone2d |    Y     |      ssl_resnet18      | 71.6451 | 91.0069 |          |          |            |
| backbone2d |    Y     |      ssl_resnet50      | 78.4069 | 94.5557 |          |          |            |
| backbone2d |    Y     |  ssl_resnext50_32x4d   | 79.3066 | 95.1356 |          |          |            |
| backbone2d |    Y     |  ssl_resnext101_32x4d  | 80.2303 | 95.4255 |          |          |            |
| backbone2d |    Y     |  ssl_resnext101_32x8d  | 81.0561 | 95.7813 |          |          |            |
| backbone2d |    Y     | ssl_resnext101_32x16d  | 81.3680 | 95.9493 |          |          |            |
| backbone2d |    Y     |     swsl_resnet18      | 72.5468 | 91.4447 |          |          |            |
| backbone2d |    Y     |     swsl_resnet50      | 80.5002 | 95.7614 |          |          |            |
| backbone2d |    Y     |  swsl_resnext50_32x4d  | 81.6319 | 96.1072 |          |          |            |
| backbone2d |    Y     | swsl_resnext101_32x4d  | 82.9135 | 96.6431 |          |          |            |
| backbone2d |    Y     | swsl_resnext101_32x8d  | 83.8732 | 97.0949 |          |          |            |
| backbone2d |    Y     | swsl_resnext101_32x16d | 83.2494 | 96.8570 |          |          |            |
| backbone2d |    Y     |       resnetrs50       | 80.2203 | 95.1975 |          |          |            |
| backbone2d |    Y     |      resnetrs101       |         |         |          |          |            |
| backbone2d |    Y     |      resnetrs152       |         |         |          |          |            |
| backbone2d |    Y     |      resnetrs200       |         |         |          |          |            |
| backbone2d |    Y     |      resnetrs270       |         |         |          |          |            |
| backbone2d |    Y     |      resnetrs350       |         |         |          |          |            |
| backbone2d |    Y     |      resnetrs420       |         |         |          |          |            |
| backbone2d |    Y     |      ecaresnet26t      | 77.0034 | 93.7780 |          |          |            |
| backbone2d |    Y     |      ecaresnet50d      | 80.1224 | 95.1236 |          |          |            |
| backbone2d |    Y     |  ecaresnet50d_pruned   |         |         |          |          |            |
| backbone2d |    Y     |      ecaresnet50t      | 79.9784 | 95.0136 |          |          |            |
| backbone2d |    Y     |     ecaresnetlight     | 79.8564 | 94.9976 |          |          |            |
| backbone2d |    Y     |     ecaresnet101d      | 81.7079 | 95.9373 |          |          |            |
| backbone2d |    Y     |  ecaresnet101d_pruned  |         |         |          |          |            |
| backbone2d |    Y     |     ecaresnet200d      |         |         |          |          |            |
| backbone2d |    Y     |     ecaresnet269d      | 82.8375 | 96.3412 |          |          |            |
| backbone2d |    Y     |  ecaresnext26t_32x4d   |         |         |          |          |            |
| backbone2d |    Y     |  ecaresnext50t_32x4d   |         |         |          |          |            |


mobilenetv3_large_075
mobilenetv3_large_100 top1:75.1859, top5:92.2965
mobilenetv3_large_100_miil top1:77.1053, top5:92.5444
mobilenetv3_large_100_miil_in21k
mobilenetv3_small_075
mobilenetv3_small_100 top1:75.1100, top5:92.3944
mobilenetv3_rw
tf_mobilenetv3_large_075 top1:73.6244, top5:91.4707
tf_mobilenetv3_large_100 top1:75.5678, top5:92.7183
tf_mobilenetv3_large_minimal_100 top1:72.5488, top5:90.7690
tf_mobilenetv3_small_075 top1:65.8289, top5:86.4523
tf_mobilenetv3_small_100 top1:68.0622, top5:87.7939
tf_mobilenetv3_small_minimal_100  top1:62.9119, top5:84.5250

mnasnet_050
mnasnet_075
mnasnet_100 top1:73.7984, top5:91.80665
mnasnet_140
semnasnet_050
semnasnet_075
semnasnet_100 top1:74.8081, top5:92.2605
semnasnet_140
mnasnet_small
mobilenetv2_100 top1:72.0429, top5:90.5470
mobilenetv2_110d top1:74.2522, top5:91.7986
mobilenetv2_120d
mobilenetv2_140 top1:75.6098, top5:92.5924
fbnetc_100 top1:74.1683, top5:91.8986
spnasnet_100 top1:71.9250, top5:90.7630
eca_efficientnet_b0
gc_efficientnet_b0
efficientnet_b0 top1:77.0833, top5:93.3061
efficientnet_b1 top1:77.0713, top5:93.3781
efficientnet_b2 top1:77.0933, top5:93.5641
efficientnet_b3 top1:77.8151, top5:94.0999
efficientnet_b4 top1:78.3429, top5:94.2179
efficientnet_b5
efficientnet_b6
efficientnet_b7
efficientnet_b8
efficientnet_l2
efficientnet_es
efficientnet_em
efficientnet_el
efficientnet_es_pruned
efficientnet_el_pruned
efficientnet_cc_b0_4e
efficientnet_cc_b0_8e
efficientnet_cc_b1_8e
efficientnet_lite0 top1:74.7061, top5:92.1345
efficientnet_lite1
efficientnet_lite2
efficientnet_lite3
efficientnet_lite4
efficientnet_b1_pruned
efficientnet_b2_pruned
efficientnet_b3_pruned
efficientnetv2_rw_t top1:80.8021, top5:95.2795
gc_efficientnetv2_rw_t
efficientnetv2_rw_s top1:80.3503, top5:95.0816
efficientnetv2_rw_m top1:81.1880, top5:95.4934
efficientnetv2_s
efficientnetv2_m
efficientnetv2_l
tf_efficientnet_b0 top1:77.3632, top5:93.4241
tf_efficientnet_b1 top1:78.9167, top5:94.2618
tf_efficientnet_b2 top1:78.6708, top5:94.2558
tf_efficientnet_b3 top1:78.7828, top5:94.1219
tf_efficientnet_b4 top1:78.4509, top5:94.1599
tf_efficientnet_b5 top1:72.1189, top5:90.6750
tf_efficientnet_b6 top1:76.5415, top5:93.3181
tf_efficientnet_b7 top1:59.8948, top5:82.0997
tf_efficientnet_b8 top1:60.9245, top5:82.5696
tf_efficientnet_b0_ap top1:77.4572, top5:93.5561
tf_efficientnet_b1_ap top1:78.4449, top5:93.8760
tf_efficientnet_b2_ap top1:78.0930, top5:93.7780
tf_efficientnet_b3_ap top1:78.3549, top5:93.8900
tf_efficientnet_b4_ap
tf_efficientnet_b5_ap
tf_efficientnet_b6_ap
tf_efficientnet_b7_ap
tf_efficientnet_b8_ap
tf_efficientnet_b0_ns
tf_efficientnet_b1_ns
tf_efficientnet_b2_ns
tf_efficientnet_b3_ns
tf_efficientnet_b4_ns
tf_efficientnet_b5_ns
tf_efficientnet_b6_ns
tf_efficientnet_b7_ns
tf_efficientnet_l2_ns_475
tf_efficientnet_l2_ns
tf_efficientnet_es
tf_efficientnet_em
tf_efficientnet_el
tf_efficientnet_cc_b0_4e
tf_efficientnet_cc_b0_8e
tf_efficientnet_cc_b1_8e
tf_efficientnet_lite0
tf_efficientnet_lite1
tf_efficientnet_lite2
tf_efficientnet_lite3
tf_efficientnet_lite4
tf_efficientnetv2_s
tf_efficientnetv2_m
tf_efficientnetv2_l
tf_efficientnetv2_s_in21ft1k
tf_efficientnetv2_m_in21ft1k
tf_efficientnetv2_l_in21ft1k
tf_efficientnetv2_s_in21k
tf_efficientnetv2_m_in21k
tf_efficientnetv2_l_in21k
tf_efficientnetv2_b0
tf_efficientnetv2_b1
tf_efficientnetv2_b2
tf_efficientnetv2_b3
mixnet_s
mixnet_m
mixnet_l
mixnet_xl
mixnet_xxl
tf_mixnet_s
tf_mixnet_m
tf_mixnet_l